abacusai.monitor_drift_and_distributions — AbacusAI documentation

# abacusai.monitor_drift_and_distributions

## Classes

`MonitorDriftAndDistributions` | Summary of important model monitoring statistics for features available in a model monitoring instance

## Module Contents

class abacusai.monitor_drift_and_distributions.MonitorDriftAndDistributions(client, featureDrifts=None, featureDistributions=None, nestedDrifts=None, forecastingMonitorSummary={}, embeddingsDistribution={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Summary of important model monitoring statistics for features available in a model monitoring instance

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - featureDrifts (list[dict]) – A list of dicts of eligible feature names and corresponding overall feature drift measures.

    - featureDistributions (list[dict]) – A list of dicts of feature names and corresponding feature distributions.

    - nestedDrifts (list[dict]) – A list of dicts of nested feature names and corresponding overall feature drift measures.

    - forecastingMonitorSummary (ForecastingMonitorSummary) – Summary of important model monitoring statistics for features available in a model monitoring instance

    - embeddingsDistribution (EmbeddingFeatureDriftDistribution) – Summary of important model monitoring statistics for features available in a model monitoring instance

  feature_drifts = None
  feature_distributions = None
  nested_drifts = None
  forecasting_monitor_summary
  embeddings_distribution
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict